@@ -7,6 +7,7 @@ from pydantic import BaseModel
 class InferenceType(str, Enum):
     OPENAI = "openai"
     BOTARIO = "botario"
+    CUSTOM_API = "custom_api"
 
 
 class LLMConfig(BaseModel):
@@ -39,3 +40,9 @@ class LLMConfig(BaseModel):
     reasoning_effort: None | Literal["low", "medium", "high"] = (
         None  # reasoning effort for o-series models. Mutually exclusive with temperature.
     )
+
+    # Custom API configuration for generic API providers
+    custom_api_config: dict | None = None
+
+    # Custom response parser code for parsing non-standard API responses
+    custom_response_parser: str | None = None
